==> 2024-11-12_17-17-56.zip: home/pi/ADMIN/CMD/REFRESHER/SCRIPTS/SCRAPER.sh <==
#!/bin/bash

ARG="$@"
SCRIPT=$(readlink -f "$0"); PID=$$
DIR=$(cd "$(dirname $SCRIPT)/.." && pwd)
HOMEDIR=$(getent passwd pi | cut -d: -f6)

SCRAPER='/opt/retropie/supplementary/skyscraper/Skyscraper'
WORKDIR="$DIR/assets/scraper"
gamelist="$WORKDIR/gamelist.xml"
rom_dir="$HOMEDIR/RetroPie/roms/mame-libretro"

# ----------------------------------------------------------------------------------------------

sudo cp "$HOMEDIR/.emulationstation/gamelists/mame-libretro/gamelist.xml" "$WORKDIR/gamelist.xml"
sudo cp "$WORKDIR/gamelist.xml" "$WORKDIR/gamelist_copy.xml"; sed -i '$d' "$WORKDIR/gamelist_copy.xml"

# ----------------------------------------------------------------------------------------------

#comment() {
# Scrape
$SCRAPER \
  -p mame-libretro \
  -s screenscraper \
  -i "$HOMEDIR/RetroPie/roms/mame-libretro" \
  -g "$WORKDIR" \
  -a "$HOMEDIR/.skyscraper/artwork.xml" \
  --flags unattendskip \
  --includefrom "$WORKDIR/downloads.txt"

# Make gamelist
$SCRAPER \
  -p mame-libretro \
  -i "$HOMEDIR/RetroPie/roms/mame-libretro" \
  -g "$WORKDIR" \
  -a "$HOMEDIR/.skyscraper/artwork.xml" \
  --flags unattend
#}
# ----------------------------------------------------------------------------------------------

sudo cp -f "$HOMEDIR/ADMIN/MENU/.assets/GAMES/.list" "$WORKDIR/.list.old"

cat "$WORKDIR/.list.old" | awk '{$1=""; print}' | sed 's/ //' | sudo tee "$WORKDIR/.list.new" >/dev/null 2>&1

cleanString() {
  local input="${1}"; local word="${2}";
  local output=$(echo "$input" | grep -E "<$word>" | awk '{$1=$1;print}' | sed "s/<$word>//g; s/<\/$word>//g")
  [[ "$word" == name ]] && output=$(echo "$output" | perl -MHTML::Entities -pe 'decode_entities($_);')
  echo "$output"
}

# ----------------------------------------------------------------------------------------------

game_count=$(grep -Ec '<game>' "$WORKDIR/gamelist.xml")

for (( n=1; n<=$game_count; n++ )); do
    data=$(awk -v p="<game>" -v n="$n" '$0~p{i++}i==n' "$WORKDIR/gamelist.xml")
    path=$(cleanString "$data" 'path'); #path=$(echo "$path" | cut -d\/ -f2-);
    name=$(echo "$path" | grep -o '[^/]*$' | cut -d. -f1)

    if [[ $(grep -c "$name" "$WORKDIR/downloads.txt") -gt 0 ]] && [[ ${#data} -gt 0 ]]; then
      title=$(cleanString "$data" 'name' | sed "s/\x27//g")
      date=$(cleanString "$data" 'releasedate');date="${date:0:4}"; [[ ${#date} -lt 1 ]] && date='19xx'
      publisher=$(cleanString "$data" 'publisher');publisher=$(echo "$publisher" | cut -d, -f1); [[ ${#publisher} -lt 1 ]] && publisher='<unknown>'
      type='JOY'

      img_path="$HOMEDIR/ADMIN/MENU/.assets/media/slideshow/mame-libretro/$name"; images=''
      images=$(find "$img_path" -regextype posix-extended -regex '.*\.(jpg|png)' -print -quit 2>/dev/null)
      [ -n "$images" ] && images="${images##*.}"

      echo "'$name' '$title' '$date' '$publisher' '$type' '$path' '$images' '[ ]'"

      [[ $(grep -c "<path>$path</path>" "$WORKDIR/gamelist_copy.xml") -lt 1 ]] && echo "${data}" | sed 's/^/\t/' | sudo tee -a "$WORKDIR/gamelist_copy.xml" >/dev/null 2>&1
    fi

done | sudo tee "$WORKDIR/new_entries" &>/dev/null

# ----------------------------------------------------------------------------------------------

for entry in $(cat "$WORKDIR/downloads.txt" | grep -o '[^/]*$' | sed 's/[.].*$//g'); do
  line=$(grep "$entry" "$WORKDIR/new_entries")
  [ ${#line} -gt 0 ] && echo "$line" | sudo tee -a "$WORKDIR/.list.new" &>/dev/null
done

sleep 1

tac "$WORKDIR/.list.new" | sort -k4,4 -t \' --output "$WORKDIR/.list.new"
grep -n '' "$WORKDIR/.list.new" | sed 's/:/ /' | sudo tee "$WORKDIR/.list.new" &>/dev/null

#cat "$WORKDIR/.list.new" | perl -MHTML::Entities -pe 'decode_entities($_);' | sudo tee "$WORKDIR/.list.new" &>/dev/null

sudo cp "$WORKDIR/.list.new" "$DIR/assets/.list"

sed -i '/^.*<\/gameList>.*$/ s/.*$/<\/gameList>/' "$WORKDIR/gamelist_copy.xml"
sudo cp "$WORKDIR/gamelist_copy.xml" "$DIR/assets/gamelist.xml"

# ----------------------------------------------------------------------------------------------

exit

==> 2024-11-23_19-50-23.zip: home/pi/ADMIN/CMD/REFRESHER/SCRIPTS/SCRAPER.sh <==
#!/bin/bash

ARG="$@"
SCRIPT=$(readlink -f "$0"); PID=$$
DIR=$(cd "$(dirname $SCRIPT)/.." && pwd)
HOMEDIR=$(getent passwd pi | cut -d: -f6)

SCRAPER='/opt/retropie/supplementary/skyscraper/Skyscraper'
WORKDIR="$DIR/assets/scraper"
gamelist="$WORKDIR/gamelist.xml"
rom_dir="$HOMEDIR/RetroPie/roms/mame-libretro"
assets_path="$HOMEDIR/ADMIN/MENU/.assets"

# ----------------------------------------------------------------------------------------------

sudo cp "$HOMEDIR/.emulationstation/gamelists/mame-libretro/gamelist.xml" "$WORKDIR/gamelist.xml"
sudo cp "$WORKDIR/gamelist.xml" "$WORKDIR/gamelist_copy.xml"; sed -i '$d' "$WORKDIR/gamelist_copy.xml"

# ----------------------------------------------------------------------------------------------

#comment() {
# Scrape
$SCRAPER \
  -p mame-libretro \
  -s screenscraper \
  -i "$HOMEDIR/RetroPie/roms/mame-libretro" \
  -g "$WORKDIR" \
  -a "$HOMEDIR/.skyscraper/artwork.xml" \
  --flags unattendskip \
  --includefrom "$WORKDIR/downloads.txt"

# Make gamelist
$SCRAPER \
  -p mame-libretro \
  -i "$HOMEDIR/RetroPie/roms/mame-libretro" \
  -g "$WORKDIR" \
  -a "$HOMEDIR/.skyscraper/artwork.xml" \
  --flags unattend
#}
# ----------------------------------------------------------------------------------------------

sudo cp -f "$assets_path/GAMES/.list" "$WORKDIR/.list.old"

cat "$WORKDIR/.list.old" | awk '{$1=""; print}' | sed 's/ //' | sudo tee "$WORKDIR/.list.new" >/dev/null 2>&1

cleanString() {
  local input="${1}"; local word="${2}";
  local output=$(echo "$input" | grep -E "<$word>" | awk '{$1=$1;print}' | sed "s/<$word>//g; s/<\/$word>//g")
  #[[ "$word" == name ]] && output=$(echo "$output" | perl -MHTML::Entities -pe 'decode_entities($_);')
  echo "$output"
}

# ----------------------------------------------------------------------------------------------

game_count=$(grep -Ec '<game>' "$WORKDIR/gamelist.xml")

for (( n=1; n<=$game_count; n++ )); do
    data=$(awk -v p="<game>" -v n="$n" '$0~p{i++}i==n' "$WORKDIR/gamelist.xml")
    path=$(cleanString "$data" 'path'); #path=$(echo "$path" | cut -d\/ -f2-);
    name=$(echo "$path" | grep -o '[^/]*$' | cut -d. -f1)

    if [[ $(grep -c "$name" "$WORKDIR/downloads.txt") -gt 0 ]] && [[ ${#data} -gt 0 ]]; then
      title=$(cleanString "$data" 'name' | sed "s/\x27//g")
      date=$(cleanString "$data" 'releasedate');date="${date:0:4}"; [[ ${#date} -lt 1 ]] && date='19xx'
      publisher=$(cleanString "$data" 'publisher');publisher=$(echo "$publisher" | cut -d, -f1); [[ ${#publisher} -lt 1 ]] && publisher='<unknown>'
      type='JOY'

      #img_path="$HOMEDIR/ADMIN/MENU/.assets/media/slideshow/mame-libretro/$name"; images=''
      #images=$(find "$img_path" -regextype posix-extended -regex '.*\.(jpg|png)' -print -quit 2>/dev/null)
      #[ -n "$images" ] && images="${images##*.}"

      find "$assets_path/media/marquees" -type f -iname "$name*" -exec false {} +; marquee=$?
      echo "'$name' '$title' '$date' '$publisher' '$type' '$path' '$marquee' '[ ]'"

      [[ $(grep -c "<path>$path</path>" "$WORKDIR/gamelist_copy.xml") -lt 1 ]] && echo "${data}" | sed 's/^/\t/' | sudo tee -a "$WORKDIR/gamelist_copy.xml" >/dev/null 2>&1
    fi

done | sudo tee "$WORKDIR/new_entries" &>/dev/null

# ----------------------------------------------------------------------------------------------

for entry in $(cat "$WORKDIR/downloads.txt" | grep -o '[^/]*$' | sed 's/[.].*$//g'); do
  line=$(grep "$entry" "$WORKDIR/new_entries")
  [ ${#line} -gt 0 ] && echo "$line" | sudo tee -a "$WORKDIR/.list.new" &>/dev/null
done

sed -i 's/&apos;//' "$WORKDIR/.list.new"

for line in "$(grep '&.*;' $WORKDIR/.list.new)"; do
  line_num=$(echo "$line" | awk '{print $1}'); line_fmt=$(echo "$line" | perl -MHTML::Entities -pe 'decode_entities($_);')
  sed -i "/${line_num}/d" "$WORKDIR/.list.new"; echo "$line_fmt" | sudo tee -a "$WORKDIR/.list.new" &>/dev/null
done


tac "$WORKDIR/.list.new" | sort -k4,4 -t \' --output "$WORKDIR/.list.new"
grep -n '' "$WORKDIR/.list.new" | sed 's/:/ /' | sudo tee "$WORKDIR/.list.new" &>/dev/null

sudo cp "$WORKDIR/.list.new" "$DIR/assets/.list"

sed -i '/^.*<\/gameList>.*$/ s/.*$/<\/gameList>/' "$WORKDIR/gamelist_copy.xml"
sudo cp "$WORKDIR/gamelist_copy.xml" "$DIR/assets/gamelist.xml"

# ----------------------------------------------------------------------------------------------

exit
